==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebKit/UIProcess/RemoteLayerTree/RemoteMonotonicTimeline.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#import "config.h"
#import "RemoteMonotonicTimeline.h"

#if ENABLE(THREADED_ANIMATIONS)

#import <wtf/MonotonicTime.h>
#import <wtf/TZoneMallocInlines.h>

namespace WebKit {

WTF_MAKE_TZONE_OR_ISO_ALLOCATED_IMPL(RemoteMonotonicTimeline);

Ref<RemoteMonotonicTimeline> RemoteMonotonicTimeline::create(TimelineID identifier, const Seconds& originTime, MonotonicTime now)
{
    auto monotonicTimeline = adoptRef(*new RemoteMonotonicTimeline(identifier, originTime));
    monotonicTimeline->updateCurrentTime(now);
    return monotonicTimeline;
}

RemoteMonotonicTimeline::RemoteMonotonicTimeline(TimelineID identifier, const Seconds& originTime)
    : RemoteAnimationTimeline(identifier, std::nullopt)
    , m_originTime(originTime)
{
}

void RemoteMonotonicTimeline::updateCurrentTime(MonotonicTime monotonicTime)
{
    m_currentTime = monotonicTime.secondsSinceEpoch() - m_originTime;
}

} // namespace WebKit

#endif // ENABLE(THREADED_ANIMATIONS)

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebKit/UIProcess/RemoteLayerTree/RemoteMonotonicTimeline.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#import "config.h"
#import "RemoteMonotonicTimeline.h"

#if ENABLE(THREADED_ANIMATIONS)

#import <wtf/MonotonicTime.h>
#import <wtf/TZoneMallocInlines.h>

namespace WebKit {

WTF_MAKE_TZONE_ALLOCATED_IMPL(RemoteMonotonicTimeline);

Ref<RemoteMonotonicTimeline> RemoteMonotonicTimeline::create(TimelineID identifier, const Seconds& originTime, MonotonicTime now)
{
    auto monotonicTimeline = adoptRef(*new RemoteMonotonicTimeline(identifier, originTime));
    monotonicTimeline->updateCurrentTime(now);
    return monotonicTimeline;
}

RemoteMonotonicTimeline::RemoteMonotonicTimeline(TimelineID identifier, const Seconds& originTime)
    : RemoteAnimationTimeline(identifier, std::nullopt)
    , m_originTime(originTime)
{
}

void RemoteMonotonicTimeline::updateCurrentTime(MonotonicTime monotonicTime)
{
    m_currentTime = monotonicTime.secondsSinceEpoch() - m_originTime;
}

} // namespace WebKit

#endif // ENABLE(THREADED_ANIMATIONS)
